@@ -24,8 +24,8 @@ from gi.repository import Gtk, Pango
 from meld.conf import _
 
 
-def layout_text_and_icon(stockid, primary_text, secondary_text=None):
-    image = Gtk.Image.new_from_icon_name(stockid, Gtk.IconSize.DIALOG)
+def layout_text_and_icon(icon_name, primary_text, secondary_text=None):
+    image = Gtk.Image.new_from_icon_name(icon_name, Gtk.IconSize.DIALOG)
     image.set_alignment(0.5, 0.5)
 
     vbox = Gtk.VBox(homogeneous=False, spacing=6)
@@ -45,6 +45,7 @@ def layout_text_and_icon(stockid, primary_text, secondary_text=None):
         secondary_label = Gtk.Label(
             "<small>{}</small>".format(secondary_text),
             wrap=True,
+            wrap_mode=Pango.WrapMode.WORD_CHAR,
             use_markup=True,
             xalign=0,
             can_focus=True,
@@ -85,7 +86,7 @@ class MsgAreaController(Gtk.HBox):
         self.__msgid = None
 
     def new_from_text_and_icon(
-            self, stockid, primary, secondary=None, buttons=None):
+            self, icon_name, primary, secondary=None, buttons=None):
         self.clear()
         msgarea = self.__msgarea = Gtk.InfoBar()
 
@@ -93,7 +94,7 @@ class MsgAreaController(Gtk.HBox):
             for (text, respid) in buttons:
                 self.add_button(text, respid)
 
-        content = layout_text_and_icon(stockid, primary, secondary)
+        content = layout_text_and_icon(icon_name, primary, secondary)
 
         content_area = msgarea.get_content_area()
         content_area.foreach(content_area.remove, None)
@@ -102,10 +103,16 @@ class MsgAreaController(Gtk.HBox):
         self.pack_start(msgarea, True, True, 0)
         return msgarea
 
-    def add_dismissable_msg(self, icon, primary, secondary):
+    def add_dismissable_msg(self, icon, primary, secondary, close_panes=None):
+        def clear_all(*args):
+            if close_panes:
+                for pane in close_panes:
+                    pane.clear()
+            else:
+                self.clear()
         msgarea = self.new_from_text_and_icon(icon, primary, secondary)
         msgarea.add_button(_("Hi_de"), Gtk.ResponseType.CLOSE)
-        msgarea.connect("response", lambda *args: self.clear())
+        msgarea.connect("response", clear_all)
         msgarea.show_all()
         return msgarea
 
