@@ -1,5 +1,7 @@
 #!/usr/bin/env python3
 
+import sys
+from compileall import compile_dir
 from os import environ, path
 from subprocess import call
 
@@ -12,3 +14,9 @@ if not environ.get('DESTDIR', ''):
     call(["glib-compile-schemas", path.join(DATA_DIR, 'glib-2.0', 'schemas')])
     print("Updating desktop database")
     call(["update-desktop-database", path.join(DATA_DIR, 'applications')])
+
+# Byte-compilation is enabled by passing the site-packages path to this script
+if len(sys.argv) > 1:
+    print('Byte-compiling Python module...')
+    python_source_install_path = sys.argv[1]
+    compile_dir(path.join(python_source_install_path, 'meld'), optimize=1)
